==> ovirt-engine-4.1.1.7.tar.gz: backend/manager/modules/common/src/main/java/org/ovirt/engine/core/common/action/ImportVmFromExternalUrlParameters.java <==
package org.ovirt.engine.core.common.action;

import javax.validation.constraints.NotNull;

import org.hibernate.validator.constraints.NotEmpty;
import org.ovirt.engine.core.common.businessentities.OriginType;
import org.ovirt.engine.core.common.businessentities.storage.VolumeType;
import org.ovirt.engine.core.compat.Guid;

public class ImportVmFromExternalUrlParameters extends VdcActionParametersBase {

    @NotEmpty
    private String url;
    private String newVmName;
    private Guid proxyHostId;
    private String virtioIsoName;

    @NotEmpty
    private String externalName;

    @NotNull
    private VolumeType volumeType;

    @NotNull
    private OriginType originType;

    @NotNull
    private Guid storageDomainId;

    private Guid quotaId;
    private Guid cpuProfileId;

    private String username;
    private String password;

    @NotNull
    private Guid clusterId;

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getNewVmName() {
        return newVmName;
    }

    public void setNewVmName(String newVmName) {
        this.newVmName = newVmName;
    }

    public Guid getProxyHostId() {
        return proxyHostId;
    }

    public void setProxyHostId(Guid proxyHostId) {
        this.proxyHostId = proxyHostId;
    }

    public String getVirtioIsoName() {
        return virtioIsoName;
    }

    public void setVirtioIsoName(String virtioIsoName) {
        this.virtioIsoName = virtioIsoName;
    }

    public String getExternalName() {
        return externalName;
    }

    public void setExternalName(String externalName) {
        this.externalName = externalName;
    }

    public Guid getQuotaId() {
        return quotaId;
    }

    public void setQuotaId(Guid quotaId) {
        this.quotaId = quotaId;
    }

    public Guid getCpuProfileId() {
        return cpuProfileId;
    }

    public void setCpuProfileId(Guid cpuProfileId) {
        this.cpuProfileId = cpuProfileId;
    }

    public VolumeType getVolumeType() {
        return volumeType;
    }

    public void setVolumeType(VolumeType volumeType) {
        this.volumeType = volumeType;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public OriginType getOriginType() {
        return originType;
    }

    public void setOriginType(OriginType originType) {
        this.originType = originType;
    }

    public Guid getStorageDomainId() {
        return storageDomainId;
    }

    public void setStorageDomainId(Guid storageDomainId) {
        this.storageDomainId = storageDomainId;
    }

    public Guid getClusterId() {
        return clusterId;
    }

    public void setClusterId(Guid clusterId) {
        this.clusterId = clusterId;
    }
}

==> ovirt-engine-4.2.2.4.tar.gz: backend/manager/modules/common/src/main/java/org/ovirt/engine/core/common/action/ImportVmFromExternalUrlParameters.java <==
package org.ovirt.engine.core.common.action;

import javax.validation.constraints.NotNull;

import org.hibernate.validator.constraints.NotEmpty;
import org.ovirt.engine.core.common.businessentities.OriginType;
import org.ovirt.engine.core.common.businessentities.storage.VolumeType;
import org.ovirt.engine.core.compat.Guid;

public class ImportVmFromExternalUrlParameters extends ActionParametersBase {

    @NotEmpty
    private String url;
    private String newVmName;
    private Guid proxyHostId;
    private String virtioIsoName;

    @NotEmpty
    private String externalName;

    @NotNull
    private VolumeType volumeType;

    @NotNull
    private OriginType originType;

    @NotNull
    private Guid storageDomainId;

    private Guid quotaId;
    private Guid cpuProfileId;

    private String username;
    private String password;

    @NotNull
    private Guid clusterId;

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getNewVmName() {
        return newVmName;
    }

    public void setNewVmName(String newVmName) {
        this.newVmName = newVmName;
    }

    public Guid getProxyHostId() {
        return proxyHostId;
    }

    public void setProxyHostId(Guid proxyHostId) {
        this.proxyHostId = proxyHostId;
    }

    public String getVirtioIsoName() {
        return virtioIsoName;
    }

    public void setVirtioIsoName(String virtioIsoName) {
        this.virtioIsoName = virtioIsoName;
    }

    public String getExternalName() {
        return externalName;
    }

    public void setExternalName(String externalName) {
        this.externalName = externalName;
    }

    public Guid getQuotaId() {
        return quotaId;
    }

    public void setQuotaId(Guid quotaId) {
        this.quotaId = quotaId;
    }

    public Guid getCpuProfileId() {
        return cpuProfileId;
    }

    public void setCpuProfileId(Guid cpuProfileId) {
        this.cpuProfileId = cpuProfileId;
    }

    public VolumeType getVolumeType() {
        return volumeType;
    }

    public void setVolumeType(VolumeType volumeType) {
        this.volumeType = volumeType;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public OriginType getOriginType() {
        return originType;
    }

    public void setOriginType(OriginType originType) {
        this.originType = originType;
    }

    public Guid getStorageDomainId() {
        return storageDomainId;
    }

    public void setStorageDomainId(Guid storageDomainId) {
        this.storageDomainId = storageDomainId;
    }

    public Guid getClusterId() {
        return clusterId;
    }

    public void setClusterId(Guid clusterId) {
        this.clusterId = clusterId;
    }
}
